@@ -66,6 +66,8 @@ LOG_EVENT_TYPE = None | Unset | LogEvent
 class GracefulRetryState:
     cur_attempt: int = 0
     success: bool = False
+    final_validation_exc: Exception | None = None
+    final_response: httpx.Response
 
     def __init__(self, retry_config: GracefulRetry) -> None:
         self._retry_config = retry_config
@@ -123,8 +125,11 @@ class GracefulRetry:
 
         return response_result in retry_on_status
 
-    def create_state(self) -> GracefulRetryState:
-        return GracefulRetryState(self)
+    def create_state(self, result: httpx.Response) -> GracefulRetryState:
+        state = GracefulRetryState(self)
+        # Only needed to handle cases where the user sets 0 as max attempts
+        state.final_response = result
+        return state
 
 
 class ThrottleRule:
